utils
=======

.. currentmodule:: tonic.utils

Tonic utils contain functions to plot events for visual inspection, padding for batching and other functions.

Plot event grid
----------------

.. autofunction:: plot_event_grid

